@@ -4,7 +4,7 @@ import bruhanimate.images as images
 import sys
 import pyfiglet
 
-def demo(screen, img, frames, time, effect_type, background, transparent):
+def show(screen, img, frames, time, effect_type, background, transparent):
     
     # CREATE THE RENDERER
     renderer = FocusRenderer(screen, frames, time, img, effect_type, background, transparent, start_frame=100)
@@ -25,7 +25,7 @@ def demo(screen, img, frames, time, effect_type, background, transparent):
 
 def main():
     image = images.text_to_image("What's Up?", padding_top_bottom=1, padding_left_right=3)
-    Screen.show(demo, args=(image, 300, 0, "plasma", " ", False))
+    Screen.show(show, args=(image, 300, 0, "plasma", " ", False))
 
 
 
